rng_set_scene

Function rng_set_scene 

pub fn rng_set_scene(scene: Scene)
Seeds the current thread’s RNG with the deterministic seed for the given Scene.

The scene is mapped to a number which is used as the seed (via set_seed_raw).