pub fn rng_set_scene(scene: Scene)Expand description
Seeds the current thread’s RNG with the deterministic seed for the given Scene.
The scene is mapped to a number which is used as the seed (via set_seed_raw).
pub fn rng_set_scene(scene: Scene)Seeds the current thread’s RNG with the deterministic seed for the given Scene.
The scene is mapped to a number which is used as the seed (via set_seed_raw).